@@ -130,14 +130,6 @@ You can also look for information at:
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Progressive-Web-Application>
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Progressive-Web-Application>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Progressive-Web-Application>
-
 =item * Search CPAN
 
 L<http://search.cpan.org/dist/Progressive-Web-Application/>
@@ -148,7 +140,7 @@ L<http://search.cpan.org/dist/Progressive-Web-Application/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2019 LNATION.
+Copyright 2019->2025 LNATION.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
